<?php

namespace app\controllers;

use Yii;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\Response;
use yii\filters\VerbFilter;
use yii\web\NotFoundHttpException;
use app\models\LoginForm;
use app\models\ContactForm;
use app\models\RegistrationForm;
use app\models\User;
use hscstudio\mimin\models\AuthAssignment;
use app\models\TUser;

class SiteController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'only' => ['logout'],
                'rules' => [
                    [
                        'actions' => ['logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
            'captcha' => [
                'class' => 'yii\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex()
    {
        return $this->render('index');
    }

    /**
     * Login action.
     *
     * @return Response|string
     */
    public function actionLogin()
    {
        
        if (!Yii::$app->user->isGuest) {
            //return $this->goHome();
            return $this->redirect(['site/index']);
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            return $this->goBack();
            //return $this->redirect(['site/index']);
        }

        $model->password = '';
        return $this->render('login', [
            'model' => $model,
        ]);



    }

    /**
     * Logout action.
     *
     * @return Response
     */
    public function actionLogout()
    {
        Yii::$app->user->logout();

        return $this->goHome();
    }

    /**
     * Displays contact page.
     *
     * @return Response|string
     */
    public function actionContact()
    {
        $model = new ContactForm();
        if ($model->load(Yii::$app->request->post()) && $model->contact(Yii::$app->params['adminEmail'])) {
            Yii::$app->session->setFlash('contactFormSubmitted');

            return $this->refresh();
        }
        return $this->render('contact', [
            'model' => $model,
        ]);
    }

    /**
     * Displays about page.
     *
     * @return string
     */
    public function actionAbout()
    {
        return $this->render('about');
    }

    /*
        Fungsi Register : Untuk menambahkan user baru
    */
    public function actionRegister()
    {
        
        $model = new User();
        $modelRole = new AuthAssignment();

        if ($model->load(Yii::$app->request->post())) {
            $password = $model->password_hash;
            //print_r($password);die;
            $model->setPassword($password);
            $model->status = 10;
            if ($model->save()) {
                $user = TUser::find()->where(['username' => $model->username])->andWhere(['email'=>$model->email])->one();
                $modelRole->item_name = "PESERTA_VOTING";
                $modelRole->user_id = $user->id;

                if($modelRole->save()){
                    Yii::$app->session->setFlash('success', 'Registrasi User Berhasil');
                }else{
                    $user->delete();
                    Yii::$app->session->setFlash('danger', 'Mohon Maaf, Registrasi User Gagal');
                }

                
            } else {
                Yii::$app->session->setFlash('danger', 'Mohon Maaf, Registrasi User Gagal');
            }

            return $this->redirect(['index']);
        } else {
            return $this->render('register_user', [
                'model' => $model,
            ]);
        }
        
    }

}
